==> moonlight-1.20-2.16.14-fabric-sources.jar: net/mehvahdjukaar/moonlight/core/client/MLRenderTypes.java <==
package net.mehvahdjukaar.moonlight.core.client;

import com.mojang.blaze3d.platform.GlStateManager;
import com.mojang.blaze3d.systems.RenderSystem;
import net.mehvahdjukaar.moonlight.api.client.CoreShaderContainer;
import net.minecraft.class_1059;
import net.minecraft.class_1060;
import net.minecraft.class_156;
import net.minecraft.class_1921;
import net.minecraft.class_287;
import net.minecraft.class_289;
import net.minecraft.class_290;
import net.minecraft.class_293;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3999;
import net.minecraft.class_4668;
import net.minecraft.class_757;
import org.jetbrains.annotations.ApiStatus;
import org.lwjgl.opengl.GL13;

import java.util.concurrent.atomic.AtomicReference;
import java.util.function.Function;
import java.util.function.Supplier;

import static net.minecraft.class_290.field_1584;

public class MLRenderTypes extends class_1921 {

    public static CoreShaderContainer TEXT_COLOR_SHADER = new CoreShaderContainer(class_757::method_34543);
    public static CoreShaderContainer PARTICLE_TRANSLUCENT_SHADER = new CoreShaderContainer(class_757::method_34546);


    public static final Function<class_2960, class_1921> COLOR_TEXT = class_156.method_34866((p) ->
    {
        class_4688 compositeState = class_4688.method_23598()
                .method_34578(new class_5942(TEXT_COLOR_SHADER))
                .method_34577(new class_4683(p,
                        false, true))
                .method_23615(field_21370)
                .method_23608(field_21383)
                .method_23617(false);
        return method_24049("moonlight_text_color_mipped",
                class_290.field_20888,
                class_293.class_5596.field_27382, 256, false, true,
                compositeState);
    });

    public static final Function<class_2960, class_1921> TEXT_MIP = class_156.method_34866((p) ->
    {
        class_4688 compositeState = class_4688.method_23598()
                .method_34578(field_29427)
                .method_34577(new class_4683(p, false, true))
                .method_23615(field_21370)
                .method_23608(field_21383)
                .method_23617(false);
        return method_24049("moonlight_text_mipped",
                class_290.field_20888,
                class_293.class_5596.field_27382, 256, false, true,
                compositeState);
    });

    public static final Function<class_2960, class_1921> ENTITY_SOLID_MIP = class_156.method_34866((resourceLocation) -> {
        class_4688 compositeState = class_1921.class_4688.method_23598()
                .method_34578(field_29450)
                .method_34577(new class_4668.class_4683(resourceLocation, false, true))
                .method_23615(field_21364)
                .method_23608(field_21383)
                .method_23611(field_21385)
                .method_23617(true);
        return method_24049("moonlight_entity_solid_mipped", class_290.field_1580,
                class_293.class_5596.field_27382,
                256, true, false,
                compositeState);
    });

    public static final Function<class_2960, class_1921> ENTITY_CUTOUT_MIP = class_156.method_34866(resourceLocation -> {
        class_4688 compositeState = class_4688.method_23598()
                .method_34578(field_29451)
                .method_34577(new class_4668.class_4683(resourceLocation, false, true))
                .method_23615(field_21364)
                .method_23608(field_21383)
                .method_23611(field_21385)
                .method_23617(true);
        return class_1921.method_24049("moonlight_entity_cutout_mipped",
                class_290.field_1580,
                class_293.class_5596.field_27382, 256, true, false,
                compositeState);
    });


    public static final class_3999 PARTICLE_ADDITIVE_TRANSLUCENCY_RENDER_TYPE = new class_3999() {
        @Override
        public void method_18130(class_287 builder, class_1060 textureManager) {
            class_310.method_1551().field_1773.method_22974().method_3316();
            RenderSystem.activeTexture(GL13.GL_TEXTURE2);
            RenderSystem.activeTexture(GL13.GL_TEXTURE0);
            //because of custom render type fuckery...

            RenderSystem.setShader(PARTICLE_TRANSLUCENT_SHADER::get);
            RenderSystem.depthMask(false);
            RenderSystem.setShaderTexture(0, class_1059.field_17898);
            RenderSystem.enableBlend();
            RenderSystem.blendFunc(GlStateManager.class_4535.SRC_ALPHA, GlStateManager.class_4534.ONE);
            builder.method_1328(class_293.class_5596.field_27382, field_1584);
        }

        @Override
        public void method_18131(class_289 tesselator) {
            tesselator.method_1350();
        }

        public String toString() {
            return "PARTICLE_SHEET_ADDITIVE_TRANSLUCENT";
        }
    };


    public MLRenderTypes(String pName, class_293 pFormat, class_293.class_5596 pMode, int pBufferSize, boolean pAffectsCrumbling, boolean pSortOnUpload, Runnable pSetupState, Runnable pClearState) {
        super(pName, pFormat, pMode, pBufferSize, pAffectsCrumbling, pSortOnUpload, pSetupState, pClearState);
    }
}

==> moonlight-1.21-2.25.0-fabric-sources.jar: net/mehvahdjukaar/moonlight/core/client/MLRenderTypes.java <==
package net.mehvahdjukaar.moonlight.core.client;

import com.mojang.blaze3d.platform.GlStateManager;
import com.mojang.blaze3d.systems.RenderSystem;
import net.mehvahdjukaar.moonlight.api.client.CoreShaderContainer;
import net.minecraft.class_1059;
import net.minecraft.class_1060;
import net.minecraft.class_156;
import net.minecraft.class_1921;
import net.minecraft.class_287;
import net.minecraft.class_289;
import net.minecraft.class_290;
import net.minecraft.class_293;
import net.minecraft.class_2960;
import net.minecraft.class_310;
import net.minecraft.class_3999;
import net.minecraft.class_4668;
import net.minecraft.class_757;
import org.lwjgl.opengl.GL13;

import java.util.concurrent.atomic.AtomicReference;
import java.util.function.Function;

import static net.minecraft.class_290.field_1584;

public class MLRenderTypes extends class_1921 {

    public static CoreShaderContainer TEXT_COLOR_SHADER = new CoreShaderContainer(class_757::method_34543);
    public static CoreShaderContainer PARTICLE_TRANSLUCENT_SHADER = new CoreShaderContainer(class_757::method_34546);


    public static final Function<class_2960, class_1921> COLOR_TEXT = class_156.method_34866((p) ->
    {
        class_4688 compositeState = class_4688.method_23598()
                .method_34578(new class_5942(TEXT_COLOR_SHADER))
                .method_34577(new class_4683(p,
                        false, true))
                .method_23615(field_21370)
                .method_23608(field_21383)
                .method_23617(false);
        return method_24049("moonlight_text_color_mipped",
                class_290.field_20888,
                class_293.class_5596.field_27382, 256, false, true,
                compositeState);
    });

    public static final Function<class_2960, class_1921> TEXT_MIP = class_156.method_34866((p) ->
    {
        class_4688 compositeState = class_4688.method_23598()
                .method_34578(field_29427)
                .method_34577(new class_4683(p, false, true))
                .method_23615(field_21370)
                .method_23608(field_21383)
                .method_23617(false);
        return method_24049("moonlight_text_mipped",
                class_290.field_20888,
                class_293.class_5596.field_27382, 256, false, true,
                compositeState);
    });

    public static final Function<class_2960, class_1921> ENTITY_SOLID_MIP = class_156.method_34866((resourceLocation) -> {
        class_4688 compositeState = class_1921.class_4688.method_23598()
                .method_34578(field_29450)
                .method_34577(new class_4668.class_4683(resourceLocation, false, true))
                .method_23615(field_21364)
                .method_23608(field_21383)
                .method_23611(field_21385)
                .method_23617(true);
        return method_24049("moonlight_entity_solid_mipped", class_290.field_1580,
                class_293.class_5596.field_27382,
                256, true, false,
                compositeState);
    });

    public static final Function<class_2960, class_1921> ENTITY_CUTOUT_MIP = class_156.method_34866(resourceLocation -> {
        class_4688 compositeState = class_4688.method_23598()
                .method_34578(field_29451)
                .method_34577(new class_4668.class_4683(resourceLocation, false, true))
                .method_23615(field_21364)
                .method_23608(field_21383)
                .method_23611(field_21385)
                .method_23617(true);
        return class_1921.method_24049("moonlight_entity_cutout_mipped",
                class_290.field_1580,
                class_293.class_5596.field_27382, 256, true, false,
                compositeState);
    });


    public static final class_3999 PARTICLE_ADDITIVE_TRANSLUCENCY_RENDER_TYPE = new class_3999() {
        @Override
        public class_287 method_18130(class_289 builder, class_1060 textureManager) {
            class_310.method_1551().field_1773.method_22974().method_3316();
            RenderSystem.activeTexture(GL13.GL_TEXTURE2);
            RenderSystem.activeTexture(GL13.GL_TEXTURE0);
            //because of custom render type fuckery...

            RenderSystem.setShader(PARTICLE_TRANSLUCENT_SHADER::get);
            RenderSystem.depthMask(false);
            RenderSystem.setShaderTexture(0, class_1059.field_17898);
            RenderSystem.enableBlend();
            RenderSystem.blendFunc(GlStateManager.class_4535.SRC_ALPHA, GlStateManager.class_4534.ONE);
            return builder.method_60827(class_293.class_5596.field_27382, field_1584);
        }

        @Override
        public String toString() {
            return "PARTICLE_SHEET_ADDITIVE_TRANSLUCENT";
        }
    };


    public MLRenderTypes(String pName, class_293 pFormat, class_293.class_5596 pMode, int pBufferSize, boolean pAffectsCrumbling, boolean pSortOnUpload, Runnable pSetupState, Runnable pClearState) {
        super(pName, pFormat, pMode, pBufferSize, pAffectsCrumbling, pSortOnUpload, pSetupState, pClearState);
    }
}
